@@ -31,11 +31,10 @@
 #include "ephy-hosts-store.h"
 #include "ephy-hosts-view.h"
 #include "ephy-prefs.h"
-#include "ephy-search-entry.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
-#include "ephy-state.h"
+#include "ephy-initial-state.h"
 #include "ephy-time-helpers.h"
 #include "ephy-urls-store.h"
 #include "ephy-urls-view.h"
@@ -90,8 +89,7 @@ static void cmd_select_all		  (GtkAction *action,
 					   EphyHistoryWindow *editor);
 static void cmd_help_contents		  (GtkAction *action,
 					   EphyHistoryWindow *editor);
-static void search_entry_search_cb	  (GtkWidget *entry,
-					   char *search_text,
+static void search_entry_changed_cb	  (GtkWidget *entry,
 					   EphyHistoryWindow *editor);
 static void
 filter_now (EphyHistoryWindow *editor, gboolean hosts, gboolean pages);
@@ -304,7 +302,7 @@ get_target_window (EphyHistoryWindow *editor)
 	}
 	else
 	{
-		return GTK_WIDGET (ephy_shell_get_active_window (ephy_shell));
+		return GTK_WIDGET (gtk_application_get_active_window (GTK_APPLICATION (ephy_shell_get_default ())));
 	}
 }
 
@@ -322,8 +320,10 @@ cmd_open_bookmarks_in_tabs (GtkAction *action,
 	for (l = selection; l; l = l->next)
 	{
 		EphyHistoryURL *url = l->data;
-		ephy_shell_new_tab (ephy_shell, window, NULL, url->url,
-			EPHY_NEW_TAB_OPEN_PAGE | EPHY_NEW_TAB_IN_EXISTING_WINDOW);
+		ephy_shell_new_tab (ephy_shell_get_default (),
+				    window, NULL, url->url,
+				    EPHY_NEW_TAB_OPEN_PAGE |
+				    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 	}
 
 	g_list_free_full (selection, (GDestroyNotify) ephy_history_url_free);
@@ -343,7 +343,8 @@ cmd_open_bookmarks_in_browser (GtkAction *action,
 	for (l = selection; l; l = l->next)
 	{
 		EphyHistoryURL *url = l->data;
-		ephy_shell_new_tab (ephy_shell, window, NULL, url->url,
+		ephy_shell_new_tab (ephy_shell_get_default (),
+				    window, NULL, url->url,
 				    EPHY_NEW_TAB_OPEN_PAGE |
 				    EPHY_NEW_TAB_IN_NEW_WINDOW);
 	}
@@ -496,7 +497,7 @@ static void
 cmd_help_contents (GtkAction *action,
 		   EphyHistoryWindow *editor)
 {
-	ephy_gui_help (GTK_WIDGET (editor), "ephy-managing-history");
+	ephy_gui_help (GTK_WIDGET (editor), "history");
 }
 
 G_DEFINE_TYPE (EphyHistoryWindow, ephy_history_window, GTK_TYPE_WINDOW)
@@ -568,7 +569,8 @@ ephy_history_window_row_activated_cb (GtkTreeView *view,
 						 path);
 	g_return_if_fail (url != NULL);
 
-	ephy_shell_new_tab (ephy_shell, NULL, NULL, url->url,
+	ephy_shell_new_tab (ephy_shell_get_default (),
+			    NULL, NULL, url->url,
 			    EPHY_NEW_TAB_OPEN_PAGE);
 	ephy_history_url_free (url);
 }
@@ -585,7 +587,8 @@ ephy_history_window_row_middle_clicked_cb (EphyHistoryView *view,
 	url = ephy_urls_store_get_url_from_path (editor->priv->urls_store, path);
 	g_return_if_fail (url != NULL);
 
-	ephy_shell_new_tab (ephy_shell, window, NULL, url->url,
+	ephy_shell_new_tab (ephy_shell_get_default (),
+			    window, NULL, url->url,
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 	ephy_history_url_free (url);
@@ -764,7 +767,7 @@ key_pressed_cb (GtkWidget *view,
 }
 
 static void
-search_entry_search_cb (GtkWidget *entry, char *search_text, EphyHistoryWindow *editor)
+search_entry_changed_cb (GtkWidget *entry, EphyHistoryWindow *editor)
 {
 	filter_now (editor, FALSE, TRUE);
 }
@@ -778,7 +781,7 @@ time_combo_changed_cb (GtkWidget *combo, EphyHistoryWindow *editor)
 static GtkWidget *
 build_search_box (EphyHistoryWindow *editor)
 {
-	GtkWidget *box, *label, *entry;
+	GtkWidget *box, *entry;
 	GtkWidget *combo;
 	char *str;
 
@@ -786,21 +789,13 @@ build_search_box (EphyHistoryWindow *editor)
 	gtk_container_set_border_width (GTK_CONTAINER (box), 6);
 	gtk_widget_show (box);
 
-	entry = ephy_search_entry_new ();
+	entry = gtk_search_entry_new ();
 	add_focus_monitor (editor, entry);
 	add_entry_monitor (editor, entry);
 	editor->priv->search_entry = entry;
     
 	gtk_widget_show_all (entry);
 
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	str = g_strconcat ("<b>", _("_Search:"), "</b>", NULL);
-	gtk_label_set_markup_with_mnemonic (GTK_LABEL (label), str);
-	g_free (str);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-	gtk_widget_show (label);
-
 	combo = gtk_combo_box_text_new ();
 	gtk_widget_show (combo);
 
@@ -830,8 +825,6 @@ build_search_box (EphyHistoryWindow *editor)
 
 	editor->priv->time_combo = combo;
 
-	gtk_box_pack_start (GTK_BOX (box),
-			    label, FALSE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (box),
 			    entry, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (box),
@@ -840,8 +833,8 @@ build_search_box (EphyHistoryWindow *editor)
 	g_signal_connect (combo, "changed",
 			  G_CALLBACK (time_combo_changed_cb),
 			  editor);
-	g_signal_connect (G_OBJECT (entry), "search",
-			  G_CALLBACK (search_entry_search_cb),
+	g_signal_connect (G_OBJECT (entry), "changed",
+			  G_CALLBACK (search_entry_changed_cb),
 			  editor);
 
 	return box;
@@ -1280,13 +1273,13 @@ ephy_history_window_constructed (GObject *object)
 			  G_CALLBACK (key_pressed_cb),
 			  editor);
 
-	ephy_state_add_window (GTK_WIDGET (editor),
-			       "history_window",
-			       450, 400, FALSE,
-			       EPHY_STATE_WINDOW_SAVE_SIZE | EPHY_STATE_WINDOW_SAVE_POSITION);
-	ephy_state_add_paned  (GTK_WIDGET (hpaned),
-			       "history_paned",
-			       130);
+	ephy_initial_state_add_window (GTK_WIDGET (editor),
+				       "history_window",
+				       450, 400, FALSE,
+				       EPHY_INITIAL_STATE_WINDOW_SAVE_SIZE | EPHY_INITIAL_STATE_WINDOW_SAVE_POSITION);
+	ephy_initial_state_add_paned  (GTK_WIDGET (hpaned),
+				       "history_paned",
+				       130);
 
 	editor->priv->cancellable = g_cancellable_new ();
 	filter_now (editor, TRUE, TRUE);
