@@ -27,10 +27,11 @@
 #ifndef EPHY_SHELL_H
 #define EPHY_SHELL_H
 
-#include "ephy-embed-shell.h"
 #include "ephy-bookmarks.h"
-#include "ephy-window.h"
+#include "ephy-embed-shell.h"
 #include "ephy-embed.h"
+#include "ephy-session.h"
+#include "ephy-window.h"
 
 #ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
@@ -58,6 +59,8 @@ typedef struct _EphyShellPrivate  EphyShellPrivate;
  * @EPHY_NEW_TAB_HOME_PAGE: loads the home page in the new tab.
  * @EPHY_NEW_TAB_NEW_PAGE: legacy synonym for @EPHY_NEW_TAB_HOME_PAGE.
  * @EPHY_NEW_TAB_OPEN_PAGE: opens the provided network-request.
+ * @EPHY_NEW_TAB_DELAYED_OPEN_PAGE: store the provided network-request
+ *        so that it will be opened when the tab is switched to.
  * @EPHY_NEW_TAB_FULLSCREEN_MODE: calls gtk_window_fullscreen on the
  *        parent window of the new tab.
  * @EPHY_NEW_TAB_DONT_SHOW_WINDOW: do not show the window where the new
@@ -84,6 +87,7 @@ typedef enum {
   EPHY_NEW_TAB_HOME_PAGE    = 1 << 0,
   EPHY_NEW_TAB_NEW_PAGE   = 1 << 1,
   EPHY_NEW_TAB_OPEN_PAGE    = 1 << 2,
+  EPHY_NEW_TAB_DELAYED_OPEN_PAGE    = 1 << 3,
 
   /* Page mode */
   EPHY_NEW_TAB_FULLSCREEN_MODE  = 1 << 4,
@@ -91,17 +95,18 @@ typedef enum {
   EPHY_NEW_TAB_PRESENT_WINDOW     = 1 << 6,
 
   /* Tabs */
-  EPHY_NEW_TAB_APPEND_LAST  = 1 << 7,
-  EPHY_NEW_TAB_APPEND_AFTER = 1 << 8,
-  EPHY_NEW_TAB_JUMP   = 1 << 9,
+  EPHY_NEW_TAB_FIRST        = 1 << 7,
+  EPHY_NEW_TAB_APPEND_LAST  = 1 << 8,
+  EPHY_NEW_TAB_APPEND_AFTER = 1 << 9,
+  EPHY_NEW_TAB_JUMP   = 1 << 10,
 
   /* Where */
-  EPHY_NEW_TAB_IN_NEW_WINDOW  = 1 << 10,
-  EPHY_NEW_TAB_IN_EXISTING_WINDOW = 1 << 11,
+  EPHY_NEW_TAB_IN_NEW_WINDOW  = 1 << 11,
+  EPHY_NEW_TAB_IN_EXISTING_WINDOW = 1 << 12,
 
   /* The way to load */
-  EPHY_NEW_TAB_FROM_EXTERNAL      = 1 << 12,
-  EPHY_NEW_TAB_DONT_COPY_HISTORY  = 1 << 13,
+  EPHY_NEW_TAB_FROM_EXTERNAL      = 1 << 13,
+  EPHY_NEW_TAB_DONT_COPY_HISTORY  = 1 << 14,
   
 } EphyNewTabFlags;
 
@@ -158,21 +163,19 @@ EphyEmbed      *ephy_shell_new_tab_full                 (EphyShell *shell,
                                                          gboolean is_popup,
                                                          guint32 user_time);
 
-GObject        *ephy_shell_get_session                  (EphyShell *shell);
+EphySession     *ephy_shell_get_session                  (EphyShell *shell);
 
-GObject        *ephy_shell_get_net_monitor              (EphyShell *shell);
+GNetworkMonitor *ephy_shell_get_net_monitor              (EphyShell *shell);
 
-EphyBookmarks  *ephy_shell_get_bookmarks                (EphyShell *shell);
+EphyBookmarks   *ephy_shell_get_bookmarks                (EphyShell *shell);
 
-GtkWidget      *ephy_shell_get_bookmarks_editor         (EphyShell *shell);
+GtkWidget       *ephy_shell_get_bookmarks_editor         (EphyShell *shell);
 
-GtkWidget      *ephy_shell_get_history_window           (EphyShell *shell);
+GtkWidget       *ephy_shell_get_history_window           (EphyShell *shell);
 
-GObject        *ephy_shell_get_pdm_dialog               (EphyShell *shell);
+GObject         *ephy_shell_get_pdm_dialog               (EphyShell *shell);
 
-GObject        *ephy_shell_get_prefs_dialog             (EphyShell *shell);
-
-GList          *ephy_shell_get_windows                  (EphyShell *shell);
+GObject         *ephy_shell_get_prefs_dialog             (EphyShell *shell);
 
 guint           ephy_shell_get_n_windows                (EphyShell *shell);
 
@@ -180,6 +183,10 @@ EphyWindow     *ephy_shell_get_main_window              (EphyShell *shell);
 
 gboolean        ephy_shell_close_all_windows            (EphyShell *shell);
 
+void            ephy_shell_open_uris                    (EphyShell *shell,
+                                                         const char **uris,
+                                                         EphyStartupFlags startup_flags,
+                                                         guint32 user_time);
 G_END_DECLS
 
 #endif
