@@ -142,8 +142,8 @@ pdm_dialog_show_help (PdmDialog *pd)
 	int id;
 
 	static char * const help_preferences[] = {
-		"managing-cookies",
-		"managing-passwords"
+		"data-cookies",
+		"data-passwords"
 	};
 
 	ephy_dialog_get_controls (EPHY_DIALOG (pd),
@@ -228,7 +228,7 @@ clear_all_dialog_response_cb (GtkDialog *dialog,
 	if (response == GTK_RESPONSE_HELP)
 	{
 		/* Show help and return early */
-		ephy_gui_help (GTK_WIDGET (dialog), "clearing-personal-data");
+		ephy_gui_help (GTK_WIDGET (dialog), "data");
 		return;
 	}
 
