@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  * Copyright © 2012 - Igalia S.L.
  *
@@ -28,6 +29,7 @@
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-session.h"
+#include "ephy-test-utils.h"
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -96,15 +98,20 @@ test_ephy_session_load (void)
     GList *l;
     EphyEmbed *embed;
     EphyWebView *view;
+    GMainLoop *loop;
 
     disable_delayed_loading ();
 
     session = ephy_shell_get_session (ephy_shell_get_default ());
     g_assert (session);
 
+    loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
+
     ret = load_session_from_string (session, session_data);
     g_assert (ret);
 
+    ephy_test_utils_ensure_web_views_are_loaded (loop);
+
     l = gtk_application_get_windows (GTK_APPLICATION (ephy_shell_get_default ()));
     g_assert (l);
     g_assert_cmpint (g_list_length (l), ==, 1);
@@ -113,13 +120,26 @@ test_ephy_session_load (void)
     g_assert (embed);
     view = ephy_embed_get_web_view (embed);
     g_assert (view);
-    g_assert_cmpstr (ephy_web_view_get_address (view), ==, "ephy-about:memory");
+    ephy_test_utils_check_ephy_web_view_address (view, "ephy-about:memory");
 
     ephy_session_clear (session);
 
     enable_delayed_loading ();
 }
 
+/* FIXME: This #ifdef should be removed once bug #695437 is fixed. */
+#ifdef HAVE_WEBKIT2
+const char *session_data_many_windows =
+"<?xml version=\"1.0\"?>"
+"<session>"
+	 "<window x=\"100\" y=\"26\" width=\"1067\" height=\"740\" active-tab=\"0\" role=\"epiphany-window-7da420dd\">"
+	   "<embed url=\"about:epiphany\" title=\"Epiphany\"/>"
+	 "</window>"
+	 "<window x=\"73\" y=\"26\" width=\"1067\" height=\"740\" active-tab=\"0\" role=\"epiphany-window-1261c786\">"
+	   "<embed url=\"about:config\" title=\"Epiphany\"/>"
+	 "</window>"
+"</session>";
+#else
 const char *session_data_many_windows =
 "<?xml version=\"1.0\"?>"
 "<session>"
@@ -130,18 +150,25 @@ const char *session_data_many_windows =
 	   "<embed url=\"about:epiphany\" title=\"Epiphany\"/>"
 	 "</window>"
 "</session>";
+#endif
 
 static void
 test_ephy_session_clear (void)
 {
   EphySession *session;
   GList *l;
+  GMainLoop *loop;
 
   disable_delayed_loading ();
 
   session = EPHY_SESSION (ephy_shell_get_session (ephy_shell_get_default ()));
+
+  loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
+
   load_session_from_string (session, session_data_many_windows);
 
+  ephy_test_utils_ensure_web_views_are_loaded (loop);
+
   l = gtk_application_get_windows (GTK_APPLICATION (ephy_shell_get_default ()));
   gtk_widget_destroy (GTK_WIDGET (l->data));
 
@@ -162,12 +189,15 @@ test_ephy_session_load_empty_session (void)
     GList *l;
     EphyEmbed *embed;
     EphyWebView *view;
+    GMainLoop *loop;
 
     disable_delayed_loading ();
 
     session = ephy_shell_get_session (ephy_shell_get_default ());
     g_assert (session);
 
+    loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
+
     ret = load_session_from_string (session, session_data_empty);
     g_assert (ret == FALSE);
 
@@ -175,8 +205,7 @@ test_ephy_session_load_empty_session (void)
      * the default empty window. Got to spin the mainloop though,
      * since the fallback is done by queueing another session
      * command. */
-    while (g_main_context_pending (NULL))
-      g_main_context_iteration (NULL, FALSE);
+    ephy_test_utils_ensure_web_views_are_loaded (loop);
 
     l = gtk_application_get_windows (GTK_APPLICATION (ephy_shell_get_default ()));
     g_assert (l);
@@ -186,7 +215,7 @@ test_ephy_session_load_empty_session (void)
     g_assert (embed);
     view = ephy_embed_get_web_view (embed);
     g_assert (view);
-    g_assert_cmpstr (ephy_web_view_get_address (view), ==, "ephy-about:overview");
+    ephy_test_utils_check_ephy_web_view_address (view, "ephy-about:overview");
 
     enable_delayed_loading ();
     ephy_session_clear (session);
@@ -200,14 +229,21 @@ test_ephy_session_load_many_windows (void)
     GList *l, *p;
     EphyEmbed *embed;
     EphyWebView *view;
+    GMainLoop *loop;
 
     disable_delayed_loading ();
 
     session = ephy_shell_get_session (ephy_shell_get_default ());
     g_assert (session);
 
+    loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
+
     ret = load_session_from_string (session, session_data_many_windows);
     g_assert (ret);
+    g_assert_cmpint (ephy_test_utils_get_web_view_ready_counter (), >=, 0);
+    g_assert_cmpint (ephy_test_utils_get_web_view_ready_counter (), <=, 2);
+
+    ephy_test_utils_ensure_web_views_are_loaded (loop);
 
     l = gtk_application_get_windows (GTK_APPLICATION (ephy_shell_get_default ()));
     g_assert (l);
@@ -218,7 +254,10 @@ test_ephy_session_load_many_windows (void)
       g_assert (embed);
       view = ephy_embed_get_web_view (embed);
       g_assert (view);
-      g_assert_cmpstr (ephy_web_view_get_address (view), ==, "ephy-about:epiphany");
+#ifndef HAVE_WEBKIT2
+      /* FIXME: This #ifndef should be removed once bug #695437 is fixed. */
+      ephy_test_utils_check_ephy_web_view_address (view, "ephy-about:epiphany");
+#endif
     }
 
     enable_delayed_loading ();
@@ -234,16 +273,23 @@ open_uris_after_loading_session (const char** uris, int final_num_windows)
     EphyEmbed *embed;
     EphyWebView *view;
     guint32 user_time;
+    GMainLoop *loop;
 
     disable_delayed_loading ();
 
     session = ephy_shell_get_session (ephy_shell_get_default ());
     g_assert (session);
 
+    loop = ephy_test_utils_setup_ensure_web_views_are_loaded ();
+
     user_time = gdk_x11_display_get_user_time (gdk_display_get_default ());
 
     ret = load_session_from_string (session, session_data_many_windows);
     g_assert (ret);
+    g_assert_cmpint (ephy_test_utils_get_web_view_ready_counter (), >=, 0);
+    g_assert_cmpint (ephy_test_utils_get_web_view_ready_counter (), <=, 2);
+
+    ephy_test_utils_ensure_web_views_are_loaded (loop);
 
     l = gtk_application_get_windows (GTK_APPLICATION (ephy_shell_get_default ()));
 
@@ -255,7 +301,10 @@ open_uris_after_loading_session (const char** uris, int final_num_windows)
       g_assert (embed);
       view = ephy_embed_get_web_view (embed);
       g_assert (view);
-      g_assert_cmpstr (ephy_web_view_get_address (view), ==, "ephy-about:epiphany");
+#ifndef HAVE_WEBKIT2
+      /* FIXME: This #ifndef should be removed once bug #695437 is fixed. */
+      ephy_test_utils_check_ephy_web_view_address (view, "ephy-about:epiphany");
+#endif
     }
 
     /* Causing a session load here should not create new windows, since we
@@ -309,6 +358,7 @@ test_ephy_session_open_empty_uri_forces_new_window (void)
     open_uris_after_loading_session (uris, 3);
 }
 
+#ifndef HAVE_WEBKIT2
 static void
 test_ephy_session_restore_tabs (void)
 {
@@ -351,8 +401,7 @@ test_ephy_session_restore_tabs (void)
   /* The active child should now be pointing to the restored tab,
      whose address is the one we copied previously. */
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (l->data));
-  g_assert_cmpstr (ephy_web_view_get_address (ephy_embed_get_web_view (embed)),
-                   ==, url);
+  ephy_test_utils_check_ephy_web_view_address (ephy_embed_get_web_view (embed), url);
   g_free (url);
 
   ephy_session_clear (session);
@@ -377,6 +426,7 @@ test_ephy_session_restore_tabs (void)
   enable_delayed_loading ();
   ephy_session_clear (session);
 }
+#endif
 
 int
 main (int argc, char *argv[])
@@ -420,8 +470,10 @@ main (int argc, char *argv[])
   g_test_add_func ("/src/ephy-session/open-empty-uri-forces-new-window",
                    test_ephy_session_open_empty_uri_forces_new_window);
 
+#ifndef HAVE_WEBKIT2
   g_test_add_func("/src/ephy-session/restore-tabs",
                   test_ephy_session_restore_tabs);
+#endif
 
   ret = g_test_run ();
 
